@@ -1,3 +1,10 @@
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
 var _             = require('lodash'),
     escomplex     = require('escomplex'),
     Parser        = require('./parser'),
@@ -16,7 +23,7 @@ module.exports = function() {
   }
 
   var fnComplexityParser = function(reportFns) {
-    return reportFns.map(function(fnReport) {
+    return _.map(reportFns, function(fnReport) {
       return {
         name: fnReport.name,
         complexity: fnReport.cyclomatic
@@ -26,7 +33,7 @@ module.exports = function() {
 
   var analyse = function(filepath, content, transformFn, onError) {
     try {
-      var report = escomplex.analyse(decoder.write(content), {noCoreSize: true}, jsParser);
+      var report = escomplex.analyse(decoder.write(content), { noCoreSize: true }, jsParser);
       var functionComplexity = fnComplexityParser(report.functions);
       var complexityReport = {
         path: filepath,
