@@ -1,4 +1,11 @@
-var _               = require('lodash'),
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
+var _                 = require('lodash'),
     CFValidationError = require('../validation_error');
 
 var DEFAULT_TASK_INFO = {
@@ -9,7 +16,7 @@ var DEFAULT_TASK_INFO = {
 var usageInfo = function(parameters) {
   var paramsInfo = function(params) {
     return _.map(params, function(param) {
-      return '--' + param.name + ' <' + param.name + '>';
+      return '--' + param.name + '=<' + param.name + '>';
     });
   };
 
