@@ -1,10 +1,17 @@
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
 var csvString     = require('csv-string'),
     StringDecoder = require('string_decoder').StringDecoder,
     logger        = require('../../log').Logger,
     command       = require('../../command');
 
 var GIT_COMMANDS_ARGS = {
-  gitlog_analysis: ['log', '--all', '-M', '-C', '--numstat', '--date=short', '--no-renames', '--pretty=format:--%h--%ad--%an'],
+  gitlog_analysis: ['log', '--all', '--numstat', '--date=short', '--no-renames', '--pretty=format:--%h--%ad--%an'],
   gitlog_messages: ['log', '--date=short', '--pretty=format:%s'],
   gitlog_revisions: ['log', '--date=iso-strict', '--pretty=format:%h,%ad'],
   git_show: ['show']
@@ -24,10 +31,20 @@ module.exports = function(repository) {
 
   var decoder = new StringDecoder();
 
+  var timePeriodArguments = function(timePeriod) {
+    var isoPeriod = timePeriod.toISOFormat();
+    return ['--after=' + isoPeriod.startDate, '--before=' + isoPeriod.endDate];
+  };
+
+  var logMessageWithTimePeriod = function(msg, timePeriod) {
+    var displayPeriod = timePeriod.toDisplayFormat();
+    logger.info(msg, ' from ' + displayPeriod.startDate + ' to ' + displayPeriod.endDate);
+  };
+
   this.revisions = function(filepath, timePeriod) {
     var gitOutput = command.run('git',
       GIT_COMMANDS_ARGS.gitlog_revisions
-      .concat(['--after=' + timePeriod.startDate, '--before=' + timePeriod.endDate])
+      .concat(timePeriodArguments(timePeriod))
       .concat([filepath]),
       {cwd: rootDir});
     var output = decoder.write(gitOutput).trim();
@@ -47,18 +64,18 @@ module.exports = function(repository) {
   };
 
   this.logStream = function(timePeriod) {
-    logger.info('Fetching git log ', 'from ' + timePeriod.startDate + ' to ' + timePeriod.endDate);
+    logMessageWithTimePeriod('Fetching git log', timePeriod);
     return command.stream('git',
       GIT_COMMANDS_ARGS.gitlog_analysis
-      .concat(['--after=' + timePeriod.startDate, '--before=' + timePeriod.endDate]),
+      .concat(timePeriodArguments(timePeriod)),
       {cwd: rootDir});
   };
 
   this.commitMessagesStream = function(timePeriod) {
-    logger.info('Fetching git messages ', 'from ' + timePeriod.startDate + ' to ' + timePeriod.endDate);
+    logMessageWithTimePeriod('Fetching git messages', timePeriod);
     return command.stream('git',
       GIT_COMMANDS_ARGS.gitlog_messages
-      .concat(['--after=' + timePeriod.startDate, '--before=' + timePeriod.endDate]),
+      .concat(timePeriodArguments(timePeriod)),
       {cwd: rootDir});
   };
 };
